# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.7.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AdviserResultResponseResultReportProducts(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'advised_manifest_changes': 'list[list[object]]',
        'advised_runtime_environment': 'RuntimeEnvironment',
        'dependency_graph': 'AdviserResultResponseResultReportDependencyGraph',
        'justification': 'Justification',
        'project': 'ProjectDef',
        'score': 'float'
    }

    attribute_map = {
        'advised_manifest_changes': 'advised_manifest_changes',
        'advised_runtime_environment': 'advised_runtime_environment',
        'dependency_graph': 'dependency_graph',
        'justification': 'justification',
        'project': 'project',
        'score': 'score'
    }

    def __init__(self, advised_manifest_changes=None, advised_runtime_environment=None, dependency_graph=None, justification=None, project=None, score=None):  # noqa: E501
        """AdviserResultResponseResultReportProducts - a model defined in Swagger"""  # noqa: E501
        self._advised_manifest_changes = None
        self._advised_runtime_environment = None
        self._dependency_graph = None
        self._justification = None
        self._project = None
        self._score = None
        self.discriminator = None
        self.advised_manifest_changes = advised_manifest_changes
        self.advised_runtime_environment = advised_runtime_environment
        self.dependency_graph = dependency_graph
        self.justification = justification
        self.project = project
        self.score = score

    @property
    def advised_manifest_changes(self):
        """Gets the advised_manifest_changes of this AdviserResultResponseResultReportProducts.  # noqa: E501

        Advised changes to manifest files  # noqa: E501

        :return: The advised_manifest_changes of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :rtype: list[list[object]]
        """
        return self._advised_manifest_changes

    @advised_manifest_changes.setter
    def advised_manifest_changes(self, advised_manifest_changes):
        """Sets the advised_manifest_changes of this AdviserResultResponseResultReportProducts.

        Advised changes to manifest files  # noqa: E501

        :param advised_manifest_changes: The advised_manifest_changes of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :type: list[list[object]]
        """
        if advised_manifest_changes is None:
            raise ValueError("Invalid value for `advised_manifest_changes`, must not be `None`")  # noqa: E501

        self._advised_manifest_changes = advised_manifest_changes

    @property
    def advised_runtime_environment(self):
        """Gets the advised_runtime_environment of this AdviserResultResponseResultReportProducts.  # noqa: E501


        :return: The advised_runtime_environment of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :rtype: RuntimeEnvironment
        """
        return self._advised_runtime_environment

    @advised_runtime_environment.setter
    def advised_runtime_environment(self, advised_runtime_environment):
        """Sets the advised_runtime_environment of this AdviserResultResponseResultReportProducts.


        :param advised_runtime_environment: The advised_runtime_environment of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :type: RuntimeEnvironment
        """

        self._advised_runtime_environment = advised_runtime_environment

    @property
    def dependency_graph(self):
        """Gets the dependency_graph of this AdviserResultResponseResultReportProducts.  # noqa: E501


        :return: The dependency_graph of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :rtype: AdviserResultResponseResultReportDependencyGraph
        """
        return self._dependency_graph

    @dependency_graph.setter
    def dependency_graph(self, dependency_graph):
        """Sets the dependency_graph of this AdviserResultResponseResultReportProducts.


        :param dependency_graph: The dependency_graph of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :type: AdviserResultResponseResultReportDependencyGraph
        """
        if dependency_graph is None:
            raise ValueError("Invalid value for `dependency_graph`, must not be `None`")  # noqa: E501

        self._dependency_graph = dependency_graph

    @property
    def justification(self):
        """Gets the justification of this AdviserResultResponseResultReportProducts.  # noqa: E501


        :return: The justification of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :rtype: Justification
        """
        return self._justification

    @justification.setter
    def justification(self, justification):
        """Sets the justification of this AdviserResultResponseResultReportProducts.


        :param justification: The justification of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :type: Justification
        """
        if justification is None:
            raise ValueError("Invalid value for `justification`, must not be `None`")  # noqa: E501

        self._justification = justification

    @property
    def project(self):
        """Gets the project of this AdviserResultResponseResultReportProducts.  # noqa: E501


        :return: The project of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :rtype: ProjectDef
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this AdviserResultResponseResultReportProducts.


        :param project: The project of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :type: ProjectDef
        """
        if project is None:
            raise ValueError("Invalid value for `project`, must not be `None`")  # noqa: E501

        self._project = project

    @property
    def score(self):
        """Gets the score of this AdviserResultResponseResultReportProducts.  # noqa: E501

        Score of the computed product  # noqa: E501

        :return: The score of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this AdviserResultResponseResultReportProducts.

        Score of the computed product  # noqa: E501

        :param score: The score of this AdviserResultResponseResultReportProducts.  # noqa: E501
        :type: float
        """
        if score is None:
            raise ValueError("Invalid value for `score`, must not be `None`")  # noqa: E501

        self._score = score

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AdviserResultResponseResultReportProducts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdviserResultResponseResultReportProducts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.7.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalysisResultResponseResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aicoe_ci': 'AnalysisResultResponseResultAicoeci',
        'cuda_version': 'object',
        'deb': 'list[AnalysisResultResponseResultDeb]',
        'deb_dependencies': 'list[AnalysisResultResponseResultDebdependencies]',
        'image_size': 'int',
        'layers': 'list[str]',
        'mercator': 'list[object]',
        'operating_system': 'object',
        'python_files': 'list[AnalysisResultResponseResultPythonfiles]',
        'python_interpreters': 'list[AnalysisResultResponseResultPythoninterpreters]',
        'python_packages': 'list[AnalysisResultResponseResultPythonpackages]',
        'rpm': 'list[str]',
        'rpm_dependencies': 'list[object]',
        'skopeo_inspect': 'ImageMetadataResponse',
        'system_symbols': 'object'
    }

    attribute_map = {
        'aicoe_ci': 'aicoe-ci',
        'cuda_version': 'cuda-version',
        'deb': 'deb',
        'deb_dependencies': 'deb-dependencies',
        'image_size': 'image_size',
        'layers': 'layers',
        'mercator': 'mercator',
        'operating_system': 'operating-system',
        'python_files': 'python-files',
        'python_interpreters': 'python-interpreters',
        'python_packages': 'python-packages',
        'rpm': 'rpm',
        'rpm_dependencies': 'rpm-dependencies',
        'skopeo_inspect': 'skopeo-inspect',
        'system_symbols': 'system-symbols'
    }

    def __init__(self, aicoe_ci=None, cuda_version=None, deb=None, deb_dependencies=None, image_size=None, layers=None, mercator=None, operating_system=None, python_files=None, python_interpreters=None, python_packages=None, rpm=None, rpm_dependencies=None, skopeo_inspect=None, system_symbols=None):  # noqa: E501
        """AnalysisResultResponseResult - a model defined in Swagger"""  # noqa: E501
        self._aicoe_ci = None
        self._cuda_version = None
        self._deb = None
        self._deb_dependencies = None
        self._image_size = None
        self._layers = None
        self._mercator = None
        self._operating_system = None
        self._python_files = None
        self._python_interpreters = None
        self._python_packages = None
        self._rpm = None
        self._rpm_dependencies = None
        self._skopeo_inspect = None
        self._system_symbols = None
        self.discriminator = None
        self.aicoe_ci = aicoe_ci
        self.cuda_version = cuda_version
        self.deb = deb
        self.deb_dependencies = deb_dependencies
        self.image_size = image_size
        self.layers = layers
        self.mercator = mercator
        self.operating_system = operating_system
        self.python_files = python_files
        self.python_interpreters = python_interpreters
        self.python_packages = python_packages
        self.rpm = rpm
        self.rpm_dependencies = rpm_dependencies
        self.skopeo_inspect = skopeo_inspect
        self.system_symbols = system_symbols

    @property
    def aicoe_ci(self):
        """Gets the aicoe_ci of this AnalysisResultResponseResult.  # noqa: E501


        :return: The aicoe_ci of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: AnalysisResultResponseResultAicoeci
        """
        return self._aicoe_ci

    @aicoe_ci.setter
    def aicoe_ci(self, aicoe_ci):
        """Sets the aicoe_ci of this AnalysisResultResponseResult.


        :param aicoe_ci: The aicoe_ci of this AnalysisResultResponseResult.  # noqa: E501
        :type: AnalysisResultResponseResultAicoeci
        """
        if aicoe_ci is None:
            raise ValueError("Invalid value for `aicoe_ci`, must not be `None`")  # noqa: E501

        self._aicoe_ci = aicoe_ci

    @property
    def cuda_version(self):
        """Gets the cuda_version of this AnalysisResultResponseResult.  # noqa: E501

        Nvidia CUDA version detected - path is the key and CUDA version is the object value   # noqa: E501

        :return: The cuda_version of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: object
        """
        return self._cuda_version

    @cuda_version.setter
    def cuda_version(self, cuda_version):
        """Sets the cuda_version of this AnalysisResultResponseResult.

        Nvidia CUDA version detected - path is the key and CUDA version is the object value   # noqa: E501

        :param cuda_version: The cuda_version of this AnalysisResultResponseResult.  # noqa: E501
        :type: object
        """
        if cuda_version is None:
            raise ValueError("Invalid value for `cuda_version`, must not be `None`")  # noqa: E501

        self._cuda_version = cuda_version

    @property
    def deb(self):
        """Gets the deb of this AnalysisResultResponseResult.  # noqa: E501

        Debian packages detected (experimental)  # noqa: E501

        :return: The deb of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: list[AnalysisResultResponseResultDeb]
        """
        return self._deb

    @deb.setter
    def deb(self, deb):
        """Sets the deb of this AnalysisResultResponseResult.

        Debian packages detected (experimental)  # noqa: E501

        :param deb: The deb of this AnalysisResultResponseResult.  # noqa: E501
        :type: list[AnalysisResultResponseResultDeb]
        """
        if deb is None:
            raise ValueError("Invalid value for `deb`, must not be `None`")  # noqa: E501

        self._deb = deb

    @property
    def deb_dependencies(self):
        """Gets the deb_dependencies of this AnalysisResultResponseResult.  # noqa: E501

        Dependencies of Debian packages detected  # noqa: E501

        :return: The deb_dependencies of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: list[AnalysisResultResponseResultDebdependencies]
        """
        return self._deb_dependencies

    @deb_dependencies.setter
    def deb_dependencies(self, deb_dependencies):
        """Sets the deb_dependencies of this AnalysisResultResponseResult.

        Dependencies of Debian packages detected  # noqa: E501

        :param deb_dependencies: The deb_dependencies of this AnalysisResultResponseResult.  # noqa: E501
        :type: list[AnalysisResultResponseResultDebdependencies]
        """
        if deb_dependencies is None:
            raise ValueError("Invalid value for `deb_dependencies`, must not be `None`")  # noqa: E501

        self._deb_dependencies = deb_dependencies

    @property
    def image_size(self):
        """Gets the image_size of this AnalysisResultResponseResult.  # noqa: E501

        Size of the container image in bytes  # noqa: E501

        :return: The image_size of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: int
        """
        return self._image_size

    @image_size.setter
    def image_size(self, image_size):
        """Sets the image_size of this AnalysisResultResponseResult.

        Size of the container image in bytes  # noqa: E501

        :param image_size: The image_size of this AnalysisResultResponseResult.  # noqa: E501
        :type: int
        """
        if image_size is None:
            raise ValueError("Invalid value for `image_size`, must not be `None`")  # noqa: E501

        self._image_size = image_size

    @property
    def layers(self):
        """Gets the layers of this AnalysisResultResponseResult.  # noqa: E501

        Container image layers, sorted based on the layer precedence   # noqa: E501

        :return: The layers of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._layers

    @layers.setter
    def layers(self, layers):
        """Sets the layers of this AnalysisResultResponseResult.

        Container image layers, sorted based on the layer precedence   # noqa: E501

        :param layers: The layers of this AnalysisResultResponseResult.  # noqa: E501
        :type: list[str]
        """
        if layers is None:
            raise ValueError("Invalid value for `layers`, must not be `None`")  # noqa: E501

        self._layers = layers

    @property
    def mercator(self):
        """Gets the mercator of this AnalysisResultResponseResult.  # noqa: E501

        Mercator (TM) output  # noqa: E501

        :return: The mercator of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: list[object]
        """
        return self._mercator

    @mercator.setter
    def mercator(self, mercator):
        """Sets the mercator of this AnalysisResultResponseResult.

        Mercator (TM) output  # noqa: E501

        :param mercator: The mercator of this AnalysisResultResponseResult.  # noqa: E501
        :type: list[object]
        """
        if mercator is None:
            raise ValueError("Invalid value for `mercator`, must not be `None`")  # noqa: E501

        self._mercator = mercator

    @property
    def operating_system(self):
        """Gets the operating_system of this AnalysisResultResponseResult.  # noqa: E501

        Operating System information  # noqa: E501

        :return: The operating_system of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: object
        """
        return self._operating_system

    @operating_system.setter
    def operating_system(self, operating_system):
        """Sets the operating_system of this AnalysisResultResponseResult.

        Operating System information  # noqa: E501

        :param operating_system: The operating_system of this AnalysisResultResponseResult.  # noqa: E501
        :type: object
        """
        if operating_system is None:
            raise ValueError("Invalid value for `operating_system`, must not be `None`")  # noqa: E501

        self._operating_system = operating_system

    @property
    def python_files(self):
        """Gets the python_files of this AnalysisResultResponseResult.  # noqa: E501

        Python files detected in the container image  # noqa: E501

        :return: The python_files of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: list[AnalysisResultResponseResultPythonfiles]
        """
        return self._python_files

    @python_files.setter
    def python_files(self, python_files):
        """Sets the python_files of this AnalysisResultResponseResult.

        Python files detected in the container image  # noqa: E501

        :param python_files: The python_files of this AnalysisResultResponseResult.  # noqa: E501
        :type: list[AnalysisResultResponseResultPythonfiles]
        """
        if python_files is None:
            raise ValueError("Invalid value for `python_files`, must not be `None`")  # noqa: E501

        self._python_files = python_files

    @property
    def python_interpreters(self):
        """Gets the python_interpreters of this AnalysisResultResponseResult.  # noqa: E501

        Python interpreters detected inside the container image  # noqa: E501

        :return: The python_interpreters of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: list[AnalysisResultResponseResultPythoninterpreters]
        """
        return self._python_interpreters

    @python_interpreters.setter
    def python_interpreters(self, python_interpreters):
        """Sets the python_interpreters of this AnalysisResultResponseResult.

        Python interpreters detected inside the container image  # noqa: E501

        :param python_interpreters: The python_interpreters of this AnalysisResultResponseResult.  # noqa: E501
        :type: list[AnalysisResultResponseResultPythoninterpreters]
        """
        if python_interpreters is None:
            raise ValueError("Invalid value for `python_interpreters`, must not be `None`")  # noqa: E501

        self._python_interpreters = python_interpreters

    @property
    def python_packages(self):
        """Gets the python_packages of this AnalysisResultResponseResult.  # noqa: E501

        Detected Python packages inside the container image  # noqa: E501

        :return: The python_packages of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: list[AnalysisResultResponseResultPythonpackages]
        """
        return self._python_packages

    @python_packages.setter
    def python_packages(self, python_packages):
        """Sets the python_packages of this AnalysisResultResponseResult.

        Detected Python packages inside the container image  # noqa: E501

        :param python_packages: The python_packages of this AnalysisResultResponseResult.  # noqa: E501
        :type: list[AnalysisResultResponseResultPythonpackages]
        """
        if python_packages is None:
            raise ValueError("Invalid value for `python_packages`, must not be `None`")  # noqa: E501

        self._python_packages = python_packages

    @property
    def rpm(self):
        """Gets the rpm of this AnalysisResultResponseResult.  # noqa: E501

        A listing of container images found inside the analyzed container image   # noqa: E501

        :return: The rpm of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._rpm

    @rpm.setter
    def rpm(self, rpm):
        """Sets the rpm of this AnalysisResultResponseResult.

        A listing of container images found inside the analyzed container image   # noqa: E501

        :param rpm: The rpm of this AnalysisResultResponseResult.  # noqa: E501
        :type: list[str]
        """
        if rpm is None:
            raise ValueError("Invalid value for `rpm`, must not be `None`")  # noqa: E501

        self._rpm = rpm

    @property
    def rpm_dependencies(self):
        """Gets the rpm_dependencies of this AnalysisResultResponseResult.  # noqa: E501

        Information about RPM packages and their dependencies  # noqa: E501

        :return: The rpm_dependencies of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: list[object]
        """
        return self._rpm_dependencies

    @rpm_dependencies.setter
    def rpm_dependencies(self, rpm_dependencies):
        """Sets the rpm_dependencies of this AnalysisResultResponseResult.

        Information about RPM packages and their dependencies  # noqa: E501

        :param rpm_dependencies: The rpm_dependencies of this AnalysisResultResponseResult.  # noqa: E501
        :type: list[object]
        """
        if rpm_dependencies is None:
            raise ValueError("Invalid value for `rpm_dependencies`, must not be `None`")  # noqa: E501

        self._rpm_dependencies = rpm_dependencies

    @property
    def skopeo_inspect(self):
        """Gets the skopeo_inspect of this AnalysisResultResponseResult.  # noqa: E501


        :return: The skopeo_inspect of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: ImageMetadataResponse
        """
        return self._skopeo_inspect

    @skopeo_inspect.setter
    def skopeo_inspect(self, skopeo_inspect):
        """Sets the skopeo_inspect of this AnalysisResultResponseResult.


        :param skopeo_inspect: The skopeo_inspect of this AnalysisResultResponseResult.  # noqa: E501
        :type: ImageMetadataResponse
        """
        if skopeo_inspect is None:
            raise ValueError("Invalid value for `skopeo_inspect`, must not be `None`")  # noqa: E501

        self._skopeo_inspect = skopeo_inspect

    @property
    def system_symbols(self):
        """Gets the system_symbols of this AnalysisResultResponseResult.  # noqa: E501

        Systems symbols detected - a path mapping to exported symbols available   # noqa: E501

        :return: The system_symbols of this AnalysisResultResponseResult.  # noqa: E501
        :rtype: object
        """
        return self._system_symbols

    @system_symbols.setter
    def system_symbols(self, system_symbols):
        """Sets the system_symbols of this AnalysisResultResponseResult.

        Systems symbols detected - a path mapping to exported symbols available   # noqa: E501

        :param system_symbols: The system_symbols of this AnalysisResultResponseResult.  # noqa: E501
        :type: object
        """
        if system_symbols is None:
            raise ValueError("Invalid value for `system_symbols`, must not be `None`")  # noqa: E501

        self._system_symbols = system_symbols

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalysisResultResponseResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalysisResultResponseResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.7.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AdviserResultResponseResultReport(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'error': 'str',
        'accepted_final_states_count': 'int',
        'discarded_final_states_count': 'int',
        'pipeline': 'AdviserResultResponseResultReportPipeline',
        'products': 'list[AdviserResultResponseResultReportProducts]',
        'resolver_iterations': 'int',
        'stack_info': 'StackInfo'
    }

    attribute_map = {
        'error': 'ERROR',
        'accepted_final_states_count': 'accepted_final_states_count',
        'discarded_final_states_count': 'discarded_final_states_count',
        'pipeline': 'pipeline',
        'products': 'products',
        'resolver_iterations': 'resolver_iterations',
        'stack_info': 'stack_info'
    }

    def __init__(self, error=None, accepted_final_states_count=None, discarded_final_states_count=None, pipeline=None, products=None, resolver_iterations=None, stack_info=None):  # noqa: E501
        """AdviserResultResponseResultReport - a model defined in Swagger"""  # noqa: E501
        self._error = None
        self._accepted_final_states_count = None
        self._discarded_final_states_count = None
        self._pipeline = None
        self._products = None
        self._resolver_iterations = None
        self._stack_info = None
        self.discriminator = None
        if error is not None:
            self.error = error
        if accepted_final_states_count is not None:
            self.accepted_final_states_count = accepted_final_states_count
        if discarded_final_states_count is not None:
            self.discarded_final_states_count = discarded_final_states_count
        if pipeline is not None:
            self.pipeline = pipeline
        if products is not None:
            self.products = products
        if resolver_iterations is not None:
            self.resolver_iterations = resolver_iterations
        if stack_info is not None:
            self.stack_info = stack_info

    @property
    def error(self):
        """Gets the error of this AdviserResultResponseResultReport.  # noqa: E501

        Error message describing advise failure  # noqa: E501

        :return: The error of this AdviserResultResponseResultReport.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this AdviserResultResponseResultReport.

        Error message describing advise failure  # noqa: E501

        :param error: The error of this AdviserResultResponseResultReport.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def accepted_final_states_count(self):
        """Gets the accepted_final_states_count of this AdviserResultResponseResultReport.  # noqa: E501

        Number of resolved states that were accepted  # noqa: E501

        :return: The accepted_final_states_count of this AdviserResultResponseResultReport.  # noqa: E501
        :rtype: int
        """
        return self._accepted_final_states_count

    @accepted_final_states_count.setter
    def accepted_final_states_count(self, accepted_final_states_count):
        """Sets the accepted_final_states_count of this AdviserResultResponseResultReport.

        Number of resolved states that were accepted  # noqa: E501

        :param accepted_final_states_count: The accepted_final_states_count of this AdviserResultResponseResultReport.  # noqa: E501
        :type: int
        """

        self._accepted_final_states_count = accepted_final_states_count

    @property
    def discarded_final_states_count(self):
        """Gets the discarded_final_states_count of this AdviserResultResponseResultReport.  # noqa: E501

        Number of states that were discarded during the resolution  # noqa: E501

        :return: The discarded_final_states_count of this AdviserResultResponseResultReport.  # noqa: E501
        :rtype: int
        """
        return self._discarded_final_states_count

    @discarded_final_states_count.setter
    def discarded_final_states_count(self, discarded_final_states_count):
        """Sets the discarded_final_states_count of this AdviserResultResponseResultReport.

        Number of states that were discarded during the resolution  # noqa: E501

        :param discarded_final_states_count: The discarded_final_states_count of this AdviserResultResponseResultReport.  # noqa: E501
        :type: int
        """

        self._discarded_final_states_count = discarded_final_states_count

    @property
    def pipeline(self):
        """Gets the pipeline of this AdviserResultResponseResultReport.  # noqa: E501


        :return: The pipeline of this AdviserResultResponseResultReport.  # noqa: E501
        :rtype: AdviserResultResponseResultReportPipeline
        """
        return self._pipeline

    @pipeline.setter
    def pipeline(self, pipeline):
        """Sets the pipeline of this AdviserResultResponseResultReport.


        :param pipeline: The pipeline of this AdviserResultResponseResultReport.  # noqa: E501
        :type: AdviserResultResponseResultReportPipeline
        """

        self._pipeline = pipeline

    @property
    def products(self):
        """Gets the products of this AdviserResultResponseResultReport.  # noqa: E501

        Products computed in the deployment, always holds only one item   # noqa: E501

        :return: The products of this AdviserResultResponseResultReport.  # noqa: E501
        :rtype: list[AdviserResultResponseResultReportProducts]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this AdviserResultResponseResultReport.

        Products computed in the deployment, always holds only one item   # noqa: E501

        :param products: The products of this AdviserResultResponseResultReport.  # noqa: E501
        :type: list[AdviserResultResponseResultReportProducts]
        """

        self._products = products

    @property
    def resolver_iterations(self):
        """Gets the resolver_iterations of this AdviserResultResponseResultReport.  # noqa: E501

        Number of iterations done by the resolver to compute products   # noqa: E501

        :return: The resolver_iterations of this AdviserResultResponseResultReport.  # noqa: E501
        :rtype: int
        """
        return self._resolver_iterations

    @resolver_iterations.setter
    def resolver_iterations(self, resolver_iterations):
        """Sets the resolver_iterations of this AdviserResultResponseResultReport.

        Number of iterations done by the resolver to compute products   # noqa: E501

        :param resolver_iterations: The resolver_iterations of this AdviserResultResponseResultReport.  # noqa: E501
        :type: int
        """

        self._resolver_iterations = resolver_iterations

    @property
    def stack_info(self):
        """Gets the stack_info of this AdviserResultResponseResultReport.  # noqa: E501


        :return: The stack_info of this AdviserResultResponseResultReport.  # noqa: E501
        :rtype: StackInfo
        """
        return self._stack_info

    @stack_info.setter
    def stack_info(self, stack_info):
        """Sets the stack_info of this AdviserResultResponseResultReport.


        :param stack_info: The stack_info of this AdviserResultResponseResultReport.  # noqa: E501
        :type: StackInfo
        """

        self._stack_info = stack_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AdviserResultResponseResultReport, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdviserResultResponseResultReport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.7.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PythonPackageVersionMetadataResponseMetadataImportlibMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'entry_points': 'list[PythonPackageVersionMetadataResponseMetadataImportlibMetadataEntryPoints]',
        'files': 'list[object]',
        'metadata': 'object',
        'requires': 'list[str]',
        'version': 'str'
    }

    attribute_map = {
        'entry_points': 'entry_points',
        'files': 'files',
        'metadata': 'metadata',
        'requires': 'requires',
        'version': 'version'
    }

    def __init__(self, entry_points=None, files=None, metadata=None, requires=None, version=None):  # noqa: E501
        """PythonPackageVersionMetadataResponseMetadataImportlibMetadata - a model defined in Swagger"""  # noqa: E501
        self._entry_points = None
        self._files = None
        self._metadata = None
        self._requires = None
        self._version = None
        self.discriminator = None
        self.entry_points = entry_points
        self.files = files
        self.metadata = metadata
        self.requires = requires
        self.version = version

    @property
    def entry_points(self):
        """Gets the entry_points of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501


        :return: The entry_points of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501
        :rtype: list[PythonPackageVersionMetadataResponseMetadataImportlibMetadataEntryPoints]
        """
        return self._entry_points

    @entry_points.setter
    def entry_points(self, entry_points):
        """Sets the entry_points of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.


        :param entry_points: The entry_points of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501
        :type: list[PythonPackageVersionMetadataResponseMetadataImportlibMetadataEntryPoints]
        """
        if entry_points is None:
            raise ValueError("Invalid value for `entry_points`, must not be `None`")  # noqa: E501

        self._entry_points = entry_points

    @property
    def files(self):
        """Gets the files of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501

        Files shipped with the Python package  # noqa: E501

        :return: The files of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501
        :rtype: list[object]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.

        Files shipped with the Python package  # noqa: E501

        :param files: The files of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501
        :type: list[object]
        """
        if files is None:
            raise ValueError("Invalid value for `files`, must not be `None`")  # noqa: E501

        self._files = files

    @property
    def metadata(self):
        """Gets the metadata of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501

        Core Python packaging metadata extracted  # noqa: E501

        :return: The metadata of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.

        Core Python packaging metadata extracted  # noqa: E501

        :param metadata: The metadata of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501
        :type: object
        """
        if metadata is None:
            raise ValueError("Invalid value for `metadata`, must not be `None`")  # noqa: E501

        self._metadata = metadata

    @property
    def requires(self):
        """Gets the requires of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501

        Python requirements of the given package  # noqa: E501

        :return: The requires of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._requires

    @requires.setter
    def requires(self, requires):
        """Sets the requires of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.

        Python requirements of the given package  # noqa: E501

        :param requires: The requires of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501
        :type: list[str]
        """
        if requires is None:
            raise ValueError("Invalid value for `requires`, must not be `None`")  # noqa: E501

        self._requires = requires

    @property
    def version(self):
        """Gets the version of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501

        Version of the Python package based on importlib metadata detection   # noqa: E501

        :return: The version of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.

        Version of the Python package based on importlib metadata detection   # noqa: E501

        :param version: The version of this PythonPackageVersionMetadataResponseMetadataImportlibMetadata.  # noqa: E501
        :type: str
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PythonPackageVersionMetadataResponseMetadataImportlibMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PythonPackageVersionMetadataResponseMetadataImportlibMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.7.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ContainerImagesResponseContainerImages(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cuda_version': 'str',
        '_datetime': 'str',
        'env_image_name': 'str',
        'env_image_tag': 'str',
        'environment_name': 'str',
        'environment_type': 'str',
        'image_analysis_url': 'str',
        'image_sha': 'str',
        'os_name': 'str',
        'os_version': 'str',
        'package_extract_document_id': 'str',
        'python_version': 'str',
        'quay_repo_url': 'str',
        'thoth_image_name': 'str',
        'thoth_image_version': 'str'
    }

    attribute_map = {
        'cuda_version': 'cuda_version',
        '_datetime': 'datetime',
        'env_image_name': 'env_image_name',
        'env_image_tag': 'env_image_tag',
        'environment_name': 'environment_name',
        'environment_type': 'environment_type',
        'image_analysis_url': 'image_analysis_url',
        'image_sha': 'image_sha',
        'os_name': 'os_name',
        'os_version': 'os_version',
        'package_extract_document_id': 'package_extract_document_id',
        'python_version': 'python_version',
        'quay_repo_url': 'quay_repo_url',
        'thoth_image_name': 'thoth_image_name',
        'thoth_image_version': 'thoth_image_version'
    }

    def __init__(self, cuda_version=None, _datetime=None, env_image_name=None, env_image_tag=None, environment_name=None, environment_type=None, image_analysis_url=None, image_sha=None, os_name=None, os_version=None, package_extract_document_id=None, python_version=None, quay_repo_url=None, thoth_image_name=None, thoth_image_version=None):  # noqa: E501
        """ContainerImagesResponseContainerImages - a model defined in Swagger"""  # noqa: E501
        self._cuda_version = None
        self.__datetime = None
        self._env_image_name = None
        self._env_image_tag = None
        self._environment_name = None
        self._environment_type = None
        self._image_analysis_url = None
        self._image_sha = None
        self._os_name = None
        self._os_version = None
        self._package_extract_document_id = None
        self._python_version = None
        self._quay_repo_url = None
        self._thoth_image_name = None
        self._thoth_image_version = None
        self.discriminator = None
        self.cuda_version = cuda_version
        self._datetime = _datetime
        self.env_image_name = env_image_name
        self.env_image_tag = env_image_tag
        self.environment_name = environment_name
        self.environment_type = environment_type
        self.image_analysis_url = image_analysis_url
        self.image_sha = image_sha
        self.os_name = os_name
        self.os_version = os_version
        self.package_extract_document_id = package_extract_document_id
        self.python_version = python_version
        self.quay_repo_url = quay_repo_url
        self.thoth_image_name = thoth_image_name
        self.thoth_image_version = thoth_image_version

    @property
    def cuda_version(self):
        """Gets the cuda_version of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The cuda_version of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._cuda_version

    @cuda_version.setter
    def cuda_version(self, cuda_version):
        """Sets the cuda_version of this ContainerImagesResponseContainerImages.


        :param cuda_version: The cuda_version of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """

        self._cuda_version = cuda_version

    @property
    def _datetime(self):
        """Gets the _datetime of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The _datetime of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self.__datetime

    @_datetime.setter
    def _datetime(self, _datetime):
        """Sets the _datetime of this ContainerImagesResponseContainerImages.


        :param _datetime: The _datetime of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """
        if _datetime is None:
            raise ValueError("Invalid value for `_datetime`, must not be `None`")  # noqa: E501

        self.__datetime = _datetime

    @property
    def env_image_name(self):
        """Gets the env_image_name of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The env_image_name of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._env_image_name

    @env_image_name.setter
    def env_image_name(self, env_image_name):
        """Sets the env_image_name of this ContainerImagesResponseContainerImages.


        :param env_image_name: The env_image_name of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """

        self._env_image_name = env_image_name

    @property
    def env_image_tag(self):
        """Gets the env_image_tag of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The env_image_tag of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._env_image_tag

    @env_image_tag.setter
    def env_image_tag(self, env_image_tag):
        """Sets the env_image_tag of this ContainerImagesResponseContainerImages.


        :param env_image_tag: The env_image_tag of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """

        self._env_image_tag = env_image_tag

    @property
    def environment_name(self):
        """Gets the environment_name of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The environment_name of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._environment_name

    @environment_name.setter
    def environment_name(self, environment_name):
        """Sets the environment_name of this ContainerImagesResponseContainerImages.


        :param environment_name: The environment_name of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """

        self._environment_name = environment_name

    @property
    def environment_type(self):
        """Gets the environment_type of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The environment_type of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._environment_type

    @environment_type.setter
    def environment_type(self, environment_type):
        """Sets the environment_type of this ContainerImagesResponseContainerImages.


        :param environment_type: The environment_type of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """
        if environment_type is None:
            raise ValueError("Invalid value for `environment_type`, must not be `None`")  # noqa: E501
        allowed_values = ["BUILDTIME", "RUNTIME"]  # noqa: E501
        if environment_type not in allowed_values:
            raise ValueError(
                "Invalid value for `environment_type` ({0}), must be one of {1}"  # noqa: E501
                .format(environment_type, allowed_values)
            )

        self._environment_type = environment_type

    @property
    def image_analysis_url(self):
        """Gets the image_analysis_url of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The image_analysis_url of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._image_analysis_url

    @image_analysis_url.setter
    def image_analysis_url(self, image_analysis_url):
        """Sets the image_analysis_url of this ContainerImagesResponseContainerImages.


        :param image_analysis_url: The image_analysis_url of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """
        if image_analysis_url is None:
            raise ValueError("Invalid value for `image_analysis_url`, must not be `None`")  # noqa: E501

        self._image_analysis_url = image_analysis_url

    @property
    def image_sha(self):
        """Gets the image_sha of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The image_sha of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._image_sha

    @image_sha.setter
    def image_sha(self, image_sha):
        """Sets the image_sha of this ContainerImagesResponseContainerImages.


        :param image_sha: The image_sha of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """

        self._image_sha = image_sha

    @property
    def os_name(self):
        """Gets the os_name of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The os_name of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._os_name

    @os_name.setter
    def os_name(self, os_name):
        """Sets the os_name of this ContainerImagesResponseContainerImages.


        :param os_name: The os_name of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """

        self._os_name = os_name

    @property
    def os_version(self):
        """Gets the os_version of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The os_version of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._os_version

    @os_version.setter
    def os_version(self, os_version):
        """Sets the os_version of this ContainerImagesResponseContainerImages.


        :param os_version: The os_version of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """

        self._os_version = os_version

    @property
    def package_extract_document_id(self):
        """Gets the package_extract_document_id of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The package_extract_document_id of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._package_extract_document_id

    @package_extract_document_id.setter
    def package_extract_document_id(self, package_extract_document_id):
        """Sets the package_extract_document_id of this ContainerImagesResponseContainerImages.


        :param package_extract_document_id: The package_extract_document_id of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """
        if package_extract_document_id is None:
            raise ValueError("Invalid value for `package_extract_document_id`, must not be `None`")  # noqa: E501

        self._package_extract_document_id = package_extract_document_id

    @property
    def python_version(self):
        """Gets the python_version of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The python_version of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._python_version

    @python_version.setter
    def python_version(self, python_version):
        """Sets the python_version of this ContainerImagesResponseContainerImages.


        :param python_version: The python_version of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """

        self._python_version = python_version

    @property
    def quay_repo_url(self):
        """Gets the quay_repo_url of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The quay_repo_url of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._quay_repo_url

    @quay_repo_url.setter
    def quay_repo_url(self, quay_repo_url):
        """Sets the quay_repo_url of this ContainerImagesResponseContainerImages.


        :param quay_repo_url: The quay_repo_url of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """
        if quay_repo_url is None:
            raise ValueError("Invalid value for `quay_repo_url`, must not be `None`")  # noqa: E501

        self._quay_repo_url = quay_repo_url

    @property
    def thoth_image_name(self):
        """Gets the thoth_image_name of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The thoth_image_name of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._thoth_image_name

    @thoth_image_name.setter
    def thoth_image_name(self, thoth_image_name):
        """Sets the thoth_image_name of this ContainerImagesResponseContainerImages.


        :param thoth_image_name: The thoth_image_name of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """

        self._thoth_image_name = thoth_image_name

    @property
    def thoth_image_version(self):
        """Gets the thoth_image_version of this ContainerImagesResponseContainerImages.  # noqa: E501


        :return: The thoth_image_version of this ContainerImagesResponseContainerImages.  # noqa: E501
        :rtype: str
        """
        return self._thoth_image_version

    @thoth_image_version.setter
    def thoth_image_version(self, thoth_image_version):
        """Sets the thoth_image_version of this ContainerImagesResponseContainerImages.


        :param thoth_image_version: The thoth_image_version of this ContainerImagesResponseContainerImages.  # noqa: E501
        :type: str
        """

        self._thoth_image_version = thoth_image_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContainerImagesResponseContainerImages, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContainerImagesResponseContainerImages):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.7.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProjectDef(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'constraints': 'list[ProjectDefConstraints]',
        'requirements': 'object',
        'requirements_locked': 'object',
        'runtime_environment': 'RuntimeEnvironment'
    }

    attribute_map = {
        'constraints': 'constraints',
        'requirements': 'requirements',
        'requirements_locked': 'requirements_locked',
        'runtime_environment': 'runtime_environment'
    }

    def __init__(self, constraints=None, requirements=None, requirements_locked=None, runtime_environment=None):  # noqa: E501
        """ProjectDef - a model defined in Swagger"""  # noqa: E501
        self._constraints = None
        self._requirements = None
        self._requirements_locked = None
        self._runtime_environment = None
        self.discriminator = None
        self.constraints = constraints
        self.requirements = requirements
        self.requirements_locked = requirements_locked
        self.runtime_environment = runtime_environment

    @property
    def constraints(self):
        """Gets the constraints of this ProjectDef.  # noqa: E501


        :return: The constraints of this ProjectDef.  # noqa: E501
        :rtype: list[ProjectDefConstraints]
        """
        return self._constraints

    @constraints.setter
    def constraints(self, constraints):
        """Sets the constraints of this ProjectDef.


        :param constraints: The constraints of this ProjectDef.  # noqa: E501
        :type: list[ProjectDefConstraints]
        """
        if constraints is None:
            raise ValueError("Invalid value for `constraints`, must not be `None`")  # noqa: E501

        self._constraints = constraints

    @property
    def requirements(self):
        """Gets the requirements of this ProjectDef.  # noqa: E501

        Requirements stating direct dependencies of the project, the format is compatible with Pipenv   # noqa: E501

        :return: The requirements of this ProjectDef.  # noqa: E501
        :rtype: object
        """
        return self._requirements

    @requirements.setter
    def requirements(self, requirements):
        """Sets the requirements of this ProjectDef.

        Requirements stating direct dependencies of the project, the format is compatible with Pipenv   # noqa: E501

        :param requirements: The requirements of this ProjectDef.  # noqa: E501
        :type: object
        """
        if requirements is None:
            raise ValueError("Invalid value for `requirements`, must not be `None`")  # noqa: E501

        self._requirements = requirements

    @property
    def requirements_locked(self):
        """Gets the requirements_locked of this ProjectDef.  # noqa: E501

        A lock file stating all the dependencies pinned to a specific version togher with an explicit Python package index configuration   # noqa: E501

        :return: The requirements_locked of this ProjectDef.  # noqa: E501
        :rtype: object
        """
        return self._requirements_locked

    @requirements_locked.setter
    def requirements_locked(self, requirements_locked):
        """Sets the requirements_locked of this ProjectDef.

        A lock file stating all the dependencies pinned to a specific version togher with an explicit Python package index configuration   # noqa: E501

        :param requirements_locked: The requirements_locked of this ProjectDef.  # noqa: E501
        :type: object
        """
        if requirements_locked is None:
            raise ValueError("Invalid value for `requirements_locked`, must not be `None`")  # noqa: E501

        self._requirements_locked = requirements_locked

    @property
    def runtime_environment(self):
        """Gets the runtime_environment of this ProjectDef.  # noqa: E501


        :return: The runtime_environment of this ProjectDef.  # noqa: E501
        :rtype: RuntimeEnvironment
        """
        return self._runtime_environment

    @runtime_environment.setter
    def runtime_environment(self, runtime_environment):
        """Sets the runtime_environment of this ProjectDef.


        :param runtime_environment: The runtime_environment of this ProjectDef.  # noqa: E501
        :type: RuntimeEnvironment
        """
        if runtime_environment is None:
            raise ValueError("Invalid value for `runtime_environment`, must not be `None`")  # noqa: E501

        self._runtime_environment = runtime_environment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectDef, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectDef):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.7.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AdviseInput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'application_stack': 'PythonStack',
        'constraints': 'str',
        'justification': 'Justification',
        'kebechet_metadata': 'KebechetMetadata',
        'labels': 'object',
        'library_usage': 'AdviseInputLibraryUsage',
        'runtime_environment': 'RuntimeEnvironment',
        'stack_info': 'StackInfo'
    }

    attribute_map = {
        'application_stack': 'application_stack',
        'constraints': 'constraints',
        'justification': 'justification',
        'kebechet_metadata': 'kebechet_metadata',
        'labels': 'labels',
        'library_usage': 'library_usage',
        'runtime_environment': 'runtime_environment',
        'stack_info': 'stack_info'
    }

    def __init__(self, application_stack=None, constraints=None, justification=None, kebechet_metadata=None, labels=None, library_usage=None, runtime_environment=None, stack_info=None):  # noqa: E501
        """AdviseInput - a model defined in Swagger"""  # noqa: E501
        self._application_stack = None
        self._constraints = None
        self._justification = None
        self._kebechet_metadata = None
        self._labels = None
        self._library_usage = None
        self._runtime_environment = None
        self._stack_info = None
        self.discriminator = None
        self.application_stack = application_stack
        if constraints is not None:
            self.constraints = constraints
        if justification is not None:
            self.justification = justification
        if kebechet_metadata is not None:
            self.kebechet_metadata = kebechet_metadata
        if labels is not None:
            self.labels = labels
        if library_usage is not None:
            self.library_usage = library_usage
        if runtime_environment is not None:
            self.runtime_environment = runtime_environment
        if stack_info is not None:
            self.stack_info = stack_info

    @property
    def application_stack(self):
        """Gets the application_stack of this AdviseInput.  # noqa: E501


        :return: The application_stack of this AdviseInput.  # noqa: E501
        :rtype: PythonStack
        """
        return self._application_stack

    @application_stack.setter
    def application_stack(self, application_stack):
        """Sets the application_stack of this AdviseInput.


        :param application_stack: The application_stack of this AdviseInput.  # noqa: E501
        :type: PythonStack
        """
        if application_stack is None:
            raise ValueError("Invalid value for `application_stack`, must not be `None`")  # noqa: E501

        self._application_stack = application_stack

    @property
    def constraints(self):
        """Gets the constraints of this AdviseInput.  # noqa: E501

        Constraints to apply during the resolution  # noqa: E501

        :return: The constraints of this AdviseInput.  # noqa: E501
        :rtype: str
        """
        return self._constraints

    @constraints.setter
    def constraints(self, constraints):
        """Sets the constraints of this AdviseInput.

        Constraints to apply during the resolution  # noqa: E501

        :param constraints: The constraints of this AdviseInput.  # noqa: E501
        :type: str
        """

        self._constraints = constraints

    @property
    def justification(self):
        """Gets the justification of this AdviseInput.  # noqa: E501


        :return: The justification of this AdviseInput.  # noqa: E501
        :rtype: Justification
        """
        return self._justification

    @justification.setter
    def justification(self, justification):
        """Sets the justification of this AdviseInput.


        :param justification: The justification of this AdviseInput.  # noqa: E501
        :type: Justification
        """

        self._justification = justification

    @property
    def kebechet_metadata(self):
        """Gets the kebechet_metadata of this AdviseInput.  # noqa: E501


        :return: The kebechet_metadata of this AdviseInput.  # noqa: E501
        :rtype: KebechetMetadata
        """
        return self._kebechet_metadata

    @kebechet_metadata.setter
    def kebechet_metadata(self, kebechet_metadata):
        """Sets the kebechet_metadata of this AdviseInput.


        :param kebechet_metadata: The kebechet_metadata of this AdviseInput.  # noqa: E501
        :type: KebechetMetadata
        """

        self._kebechet_metadata = kebechet_metadata

    @property
    def labels(self):
        """Gets the labels of this AdviseInput.  # noqa: E501

        Labels used to label the request  # noqa: E501

        :return: The labels of this AdviseInput.  # noqa: E501
        :rtype: object
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this AdviseInput.

        Labels used to label the request  # noqa: E501

        :param labels: The labels of this AdviseInput.  # noqa: E501
        :type: object
        """

        self._labels = labels

    @property
    def library_usage(self):
        """Gets the library_usage of this AdviseInput.  # noqa: E501


        :return: The library_usage of this AdviseInput.  # noqa: E501
        :rtype: AdviseInputLibraryUsage
        """
        return self._library_usage

    @library_usage.setter
    def library_usage(self, library_usage):
        """Sets the library_usage of this AdviseInput.


        :param library_usage: The library_usage of this AdviseInput.  # noqa: E501
        :type: AdviseInputLibraryUsage
        """

        self._library_usage = library_usage

    @property
    def runtime_environment(self):
        """Gets the runtime_environment of this AdviseInput.  # noqa: E501


        :return: The runtime_environment of this AdviseInput.  # noqa: E501
        :rtype: RuntimeEnvironment
        """
        return self._runtime_environment

    @runtime_environment.setter
    def runtime_environment(self, runtime_environment):
        """Sets the runtime_environment of this AdviseInput.


        :param runtime_environment: The runtime_environment of this AdviseInput.  # noqa: E501
        :type: RuntimeEnvironment
        """

        self._runtime_environment = runtime_environment

    @property
    def stack_info(self):
        """Gets the stack_info of this AdviseInput.  # noqa: E501


        :return: The stack_info of this AdviseInput.  # noqa: E501
        :rtype: StackInfo
        """
        return self._stack_info

    @stack_info.setter
    def stack_info(self, stack_info):
        """Sets the stack_info of this AdviseInput.


        :param stack_info: The stack_info of this AdviseInput.  # noqa: E501
        :type: StackInfo
        """

        self._stack_info = stack_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AdviseInput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdviseInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.7.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from thamos.swagger_client.api_client import ApiClient


class ContainerImagesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def list_thoth_container_images(self, **kwargs):  # noqa: E501
        """List available Thoth container images  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_thoth_container_images(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Page offset in pagination
        :param int per_page: Number of items returned per page
        :param str os_name: Name of the operating system to consider
        :param str os_version: Version of the operating system to consider
        :param str python_version: Version of Python interpreter provided
        :param str cuda_version: Filter based on CUDA version available
        :param str image_name: Filter based on the image name
        :param str library_name: Filter based on library name
        :param str symbol: Filter based on symbol
        :param str package_name: Filter based on Python package name
        :param str rpm_package_name: Filter based on RPM package name
        :return: ContainerImagesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_thoth_container_images_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_thoth_container_images_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_thoth_container_images_with_http_info(self, **kwargs):  # noqa: E501
        """List available Thoth container images  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_thoth_container_images_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Page offset in pagination
        :param int per_page: Number of items returned per page
        :param str os_name: Name of the operating system to consider
        :param str os_version: Version of the operating system to consider
        :param str python_version: Version of Python interpreter provided
        :param str cuda_version: Filter based on CUDA version available
        :param str image_name: Filter based on the image name
        :param str library_name: Filter based on library name
        :param str symbol: Filter based on symbol
        :param str package_name: Filter based on Python package name
        :param str rpm_package_name: Filter based on RPM package name
        :return: ContainerImagesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page', 'per_page', 'os_name', 'os_version', 'python_version', 'cuda_version', 'image_name', 'library_name', 'symbol', 'package_name', 'rpm_package_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_thoth_container_images" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501
        if 'os_name' in params:
            query_params.append(('os_name', params['os_name']))  # noqa: E501
        if 'os_version' in params:
            query_params.append(('os_version', params['os_version']))  # noqa: E501
        if 'python_version' in params:
            query_params.append(('python_version', params['python_version']))  # noqa: E501
        if 'cuda_version' in params:
            query_params.append(('cuda_version', params['cuda_version']))  # noqa: E501
        if 'image_name' in params:
            query_params.append(('image_name', params['image_name']))  # noqa: E501
        if 'library_name' in params:
            query_params.append(('library_name', params['library_name']))  # noqa: E501
        if 'symbol' in params:
            query_params.append(('symbol', params['symbol']))  # noqa: E501
        if 'package_name' in params:
            query_params.append(('package_name', params['package_name']))  # noqa: E501
        if 'rpm_package_name' in params:
            query_params.append(('rpm_package_name', params['rpm_package_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/container-images', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContainerImagesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.7.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalysisResultResponseMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'analyzer': 'str',
        'analyzer_version': 'str',
        'arguments': 'object',
        '_datetime': 'str',
        'distribution': 'AdviserResultResponseMetadataDistribution',
        'document_id': 'str',
        'duration': 'int',
        'hostname': 'str',
        'os_release': 'object',
        'python': 'AdviserResultResponseMetadataPython',
        'thoth_deployment_name': 'str',
        'timestamp': 'int'
    }

    attribute_map = {
        'analyzer': 'analyzer',
        'analyzer_version': 'analyzer_version',
        'arguments': 'arguments',
        '_datetime': 'datetime',
        'distribution': 'distribution',
        'document_id': 'document_id',
        'duration': 'duration',
        'hostname': 'hostname',
        'os_release': 'os_release',
        'python': 'python',
        'thoth_deployment_name': 'thoth_deployment_name',
        'timestamp': 'timestamp'
    }

    def __init__(self, analyzer=None, analyzer_version=None, arguments=None, _datetime=None, distribution=None, document_id=None, duration=None, hostname=None, os_release=None, python=None, thoth_deployment_name=None, timestamp=None):  # noqa: E501
        """AnalysisResultResponseMetadata - a model defined in Swagger"""  # noqa: E501
        self._analyzer = None
        self._analyzer_version = None
        self._arguments = None
        self.__datetime = None
        self._distribution = None
        self._document_id = None
        self._duration = None
        self._hostname = None
        self._os_release = None
        self._python = None
        self._thoth_deployment_name = None
        self._timestamp = None
        self.discriminator = None
        self.analyzer = analyzer
        self.analyzer_version = analyzer_version
        self.arguments = arguments
        self._datetime = _datetime
        self.distribution = distribution
        self.document_id = document_id
        self.duration = duration
        self.hostname = hostname
        self.os_release = os_release
        self.python = python
        self.thoth_deployment_name = thoth_deployment_name
        self.timestamp = timestamp

    @property
    def analyzer(self):
        """Gets the analyzer of this AnalysisResultResponseMetadata.  # noqa: E501

        Analyzer name which handled container image analysis   # noqa: E501

        :return: The analyzer of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._analyzer

    @analyzer.setter
    def analyzer(self, analyzer):
        """Sets the analyzer of this AnalysisResultResponseMetadata.

        Analyzer name which handled container image analysis   # noqa: E501

        :param analyzer: The analyzer of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: str
        """
        if analyzer is None:
            raise ValueError("Invalid value for `analyzer`, must not be `None`")  # noqa: E501

        self._analyzer = analyzer

    @property
    def analyzer_version(self):
        """Gets the analyzer_version of this AnalysisResultResponseMetadata.  # noqa: E501

        Version of analyzer handling the container image analysis   # noqa: E501

        :return: The analyzer_version of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._analyzer_version

    @analyzer_version.setter
    def analyzer_version(self, analyzer_version):
        """Sets the analyzer_version of this AnalysisResultResponseMetadata.

        Version of analyzer handling the container image analysis   # noqa: E501

        :param analyzer_version: The analyzer_version of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: str
        """
        if analyzer_version is None:
            raise ValueError("Invalid value for `analyzer_version`, must not be `None`")  # noqa: E501

        self._analyzer_version = analyzer_version

    @property
    def arguments(self):
        """Gets the arguments of this AnalysisResultResponseMetadata.  # noqa: E501

        Arguments passed to the analyzer  # noqa: E501

        :return: The arguments of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: object
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this AnalysisResultResponseMetadata.

        Arguments passed to the analyzer  # noqa: E501

        :param arguments: The arguments of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: object
        """
        if arguments is None:
            raise ValueError("Invalid value for `arguments`, must not be `None`")  # noqa: E501

        self._arguments = arguments

    @property
    def _datetime(self):
        """Gets the _datetime of this AnalysisResultResponseMetadata.  # noqa: E501

        Date and time of analysis end in ISO format  # noqa: E501

        :return: The _datetime of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self.__datetime

    @_datetime.setter
    def _datetime(self, _datetime):
        """Sets the _datetime of this AnalysisResultResponseMetadata.

        Date and time of analysis end in ISO format  # noqa: E501

        :param _datetime: The _datetime of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: str
        """
        if _datetime is None:
            raise ValueError("Invalid value for `_datetime`, must not be `None`")  # noqa: E501

        self.__datetime = _datetime

    @property
    def distribution(self):
        """Gets the distribution of this AnalysisResultResponseMetadata.  # noqa: E501


        :return: The distribution of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: AdviserResultResponseMetadataDistribution
        """
        return self._distribution

    @distribution.setter
    def distribution(self, distribution):
        """Sets the distribution of this AnalysisResultResponseMetadata.


        :param distribution: The distribution of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: AdviserResultResponseMetadataDistribution
        """
        if distribution is None:
            raise ValueError("Invalid value for `distribution`, must not be `None`")  # noqa: E501

        self._distribution = distribution

    @property
    def document_id(self):
        """Gets the document_id of this AnalysisResultResponseMetadata.  # noqa: E501

        A unique identifier of the document  # noqa: E501

        :return: The document_id of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this AnalysisResultResponseMetadata.

        A unique identifier of the document  # noqa: E501

        :param document_id: The document_id of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: str
        """
        if document_id is None:
            raise ValueError("Invalid value for `document_id`, must not be `None`")  # noqa: E501

        self._document_id = document_id

    @property
    def duration(self):
        """Gets the duration of this AnalysisResultResponseMetadata.  # noqa: E501

        Number of seconds for which the analyzer was running   # noqa: E501

        :return: The duration of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this AnalysisResultResponseMetadata.

        Number of seconds for which the analyzer was running   # noqa: E501

        :param duration: The duration of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: int
        """
        if duration is None:
            raise ValueError("Invalid value for `duration`, must not be `None`")  # noqa: E501

        self._duration = duration

    @property
    def hostname(self):
        """Gets the hostname of this AnalysisResultResponseMetadata.  # noqa: E501

        Pod name where the analysis was done  # noqa: E501

        :return: The hostname of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this AnalysisResultResponseMetadata.

        Pod name where the analysis was done  # noqa: E501

        :param hostname: The hostname of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: str
        """
        if hostname is None:
            raise ValueError("Invalid value for `hostname`, must not be `None`")  # noqa: E501

        self._hostname = hostname

    @property
    def os_release(self):
        """Gets the os_release of this AnalysisResultResponseMetadata.  # noqa: E501


        :return: The os_release of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: object
        """
        return self._os_release

    @os_release.setter
    def os_release(self, os_release):
        """Sets the os_release of this AnalysisResultResponseMetadata.


        :param os_release: The os_release of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: object
        """
        if os_release is None:
            raise ValueError("Invalid value for `os_release`, must not be `None`")  # noqa: E501

        self._os_release = os_release

    @property
    def python(self):
        """Gets the python of this AnalysisResultResponseMetadata.  # noqa: E501


        :return: The python of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: AdviserResultResponseMetadataPython
        """
        return self._python

    @python.setter
    def python(self, python):
        """Sets the python of this AnalysisResultResponseMetadata.


        :param python: The python of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: AdviserResultResponseMetadataPython
        """
        if python is None:
            raise ValueError("Invalid value for `python`, must not be `None`")  # noqa: E501

        self._python = python

    @property
    def thoth_deployment_name(self):
        """Gets the thoth_deployment_name of this AnalysisResultResponseMetadata.  # noqa: E501

        Name of Thoth's deployment that computed results  # noqa: E501

        :return: The thoth_deployment_name of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._thoth_deployment_name

    @thoth_deployment_name.setter
    def thoth_deployment_name(self, thoth_deployment_name):
        """Sets the thoth_deployment_name of this AnalysisResultResponseMetadata.

        Name of Thoth's deployment that computed results  # noqa: E501

        :param thoth_deployment_name: The thoth_deployment_name of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: str
        """
        if thoth_deployment_name is None:
            raise ValueError("Invalid value for `thoth_deployment_name`, must not be `None`")  # noqa: E501

        self._thoth_deployment_name = thoth_deployment_name

    @property
    def timestamp(self):
        """Gets the timestamp of this AnalysisResultResponseMetadata.  # noqa: E501

        Timestamp when results were computed  # noqa: E501

        :return: The timestamp of this AnalysisResultResponseMetadata.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this AnalysisResultResponseMetadata.

        Timestamp when results were computed  # noqa: E501

        :param timestamp: The timestamp of this AnalysisResultResponseMetadata.  # noqa: E501
        :type: int
        """
        if timestamp is None:
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalysisResultResponseMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalysisResultResponseMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
